scoretools.Score
================

.. abjad-lineage:: abjad.tools.scoretools.Score.Score.Score

.. autoclass:: abjad.tools.scoretools.Score.Score.Score
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.descendants
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.leaves
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.lineage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.music
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.override
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.parent
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.parentage
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.prolation
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.set
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.spanners
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.start_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.storage_format
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.timespan
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.context_name
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.scoretools.Score.Score.Score.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.Score.Score.Score.append
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.index
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__add__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__iadd__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__imul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__le__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__radd__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.Score.Score.Score.__setitem__
   :noindex:
